==> libnet-sftp-ruby_0.9.0.orig.tar.gz: net-sftp-0.9.0/lib/net/sftp/protocol/05/services.rb <==
#--
# =============================================================================
# Copyright (c) 2004, Jamis Buck (jgb3@email.byu.edu)
# All rights reserved.
#
# This source file is distributed as part of the Net::SFTP Secure FTP Client
# library for Ruby. This file (and the library as a whole) may be used only as
# allowed by either the BSD license, or the Ruby license (or, by association
# with the Ruby license, the GPL). See the "doc" subdirectory of the Net::SFTP
# distribution for the texts of these licenses.
# -----------------------------------------------------------------------------
# net-sftp website: http://net-ssh.rubyforge.org/sftp
# project website : http://rubyforge.org/projects/net-ssh
# =============================================================================
#++

module Net ; module SFTP ; module Protocol ; module V_05

  def register_services( container )
    container.namespace_define :v_05 do |ns|

      ns.packet_assistant do |c,|
        require 'net/sftp/protocol/04/packet-assistant'
        V_04::PacketAssistant.new( c[:transport][:buffers],
                             c[:driver] )
      end

      ns.attr_factory do |c,|
        require 'net/sftp/protocol/04/attributes'
        V_04::Attributes.init( c[:transport][:buffers] )
      end

      ns.impl do |c,|
        require 'net/sftp/protocol/04/impl'
        V_04::Impl.new( c[:transport][:buffers],
                  c[:driver], c[:packet_assistant],
                  c[:attr_factory] )
      end

    end
  end
  module_function :register_services

end ; end ; end ; end

==> libnet-sftp-ruby_1.1.0.orig.tar.gz: net-sftp-1.1.0/lib/net/sftp/protocol/05/services.rb <==
#--
# =============================================================================
# Copyright (c) 2004, Jamis Buck (jamis@37signals.com)
# All rights reserved.
#
# This source file is distributed as part of the Net::SFTP Secure FTP Client
# library for Ruby. This file (and the library as a whole) may be used only as
# allowed by either the BSD license, or the Ruby license (or, by association
# with the Ruby license, the GPL). See the "doc" subdirectory of the Net::SFTP
# distribution for the texts of these licenses.
# -----------------------------------------------------------------------------
# net-sftp website: http://net-ssh.rubyforge.org/sftp
# project website : http://rubyforge.org/projects/net-ssh
# =============================================================================
#++

module Net ; module SFTP ; module Protocol ; module V_05

  def register_services( container )
    container.namespace_define :v_05 do |ns|

      ns.packet_assistant do |c,|
        require 'net/sftp/protocol/05/packet-assistant'
        PacketAssistant.new( c[:transport][:buffers],
                             c[:driver] )
      end

      ns.attr_factory do |c,|
        require 'net/sftp/protocol/04/attributes'
        V_04::Attributes.init( c[:transport][:buffers] )
      end

      ns.impl do |c,|
        require 'net/sftp/protocol/05/impl'
        Impl.new( c[:transport][:buffers],
                  c[:driver], c[:packet_assistant],
                  c[:attr_factory] )
      end

    end
  end
  module_function :register_services

end ; end ; end ; end
